local MinBuild, MaxBuild, Build = 40000, 0, select(4, GetBuildInfo())
if Build < MinBuild or ( MaxBuild > 0 and Build > MaxBuild ) then return end

local AddonName, AddonTable = ...
local s = SpellFlashAddon
local c = BittenSpellFlashLibrary
AddonTable.Spells = {}
local spells = AddonTable.Spells

function c.hasThreeHolyPower()
	return s.Power("player", SPELL_POWER_HOLY_POWER) == 3
end


------------------------------------------------------------------------ common
spells["Avenging Wrath"] = {
	SpellID = 31884,
	NonGCD = true,
}

spells["Word of Glory"] = {
	SpellID = 85673,
}

spells["Word of Glory at 90"] = {
	SpellID = 85673,
	OverrideCheck = function()
		-- not sure why we have to override, but it wasn't working as ExtraCheck
		return c.hasThreeHolyPower() 
			and s.HealthPercent("player") < 90
			and not c.isOnCooldown("Word of Glory")
	end
}

spells["Inquisition"] = {
	SpellID = 84963,
	Buff = "Inquisition",
	BuffUnit = "player",
	EarlyRefresh = 3,
	ExtraCheck = function()
		return c.hasThreeHolyPower()
	end
}

spells["Crusader Strike"] = {
	SpellID = 35395,
}

spells["Crusader Strike for Holy Power"] = {
	SpellID = 35395,
	ExtraCheck = function()
		return not c.hasThreeHolyPower()
	end
}

spells["Seal of Truth"] = {
	SpellID = 31801,
	ExtraCheck = function()
		return not c.hasBuff("Seal of Truth", 0, 15 * 60)
	end
}

spells["Seal of Insight"] = {
	SpellID = 20165,
	ExtraCheck = function()
		return not c.hasBuff("Seal of Insight", 0, 15 * 60)
	end
}

spells["Hammer of Wrath"] = {
	SpellID = 24275,
}

spells["Judgement"] = {
	SpellID = 20271,
}

spells["Judgements of the Pure"] = {
	SpellID = 20271,
	Buff = "Judgements of the Pure",
	BuffUnit = "player",
	EarlyRefresh = 5
}

spells["Consecration over 50"] = {
	SpellID = 26573,
	ExtraCheck = function()
		return s.PowerPercent("player") > 50
	end
}

spells["Holy Wrath"] = {
	SpellID = 2812,
}

spells["Divine Plea"] = {
	SpellID = 54428,
}

-------------------------------------------------------------------------- holy
spells["Judgement for Buff"] = {
	SpellID = 20271,
	Buff = "Judgements of the Pure",
	BuffUnit = "player",
}

spells["Word of Glory at 3"] = {
	SpellID = 85673,
	OverrideCheck = function()
		-- not sure why we have to override, but it wasn't working as ExtraCheck
		return c.hasThreeHolyPower() 
			and not c.isOnCooldown("Word of Glory")
	end
}

spells["Holy Shock"] = {
	SpellID = 20473,
}

spells["Fast Divine Light"] = {
	SpellID = 82326,
	OverrideCheck = function()
		return s.Buff("Infusion of Light", "player")
	end
}

spells["Holy Radiance"] = {
	SpellID = 82327,
}

------------------------------------------------------------------- retribution
spells["Free Exorsism"] = {
	SpellID = 879,
	ExtraCheck = function()
		return s.Buff("The Art of War", "player")
	end
}

spells["Free Exorsism against Undead"] = {
	SpellID = 879,
	ExtraCheck = function()
		return s.Buff("The Art of War", "player")
			and UnitCreatureType("target") == "Undead"
	end
}

spells["Templar's Verdict"] = {
	SpellID = 85256,
	ExtraCheck = function()
		return c.hasThreeHolyPower()
	end
}

spells["Zealotry"] = {
	SpellID = 85696,
	NonGCD = true,
}

-------------------------------------------------------------------- protection
spells["Shield of the Righteous unless WoG"] = {
	SpellID = 53600,
	ExtraCheck = function()
		return c.hasThreeHolyPower() and c.getCooldown("Word of Glory") > 10
	end
}

spells["Avenger's Shield"] = {
	SpellID = 31935,
}

spells["Avenger's Shield for Holy Power"] = {
	SpellID = 31935,
	ExtraCheck = function()
		return s.Buff("Grand Crusader", "player")
	end
}

spells["Ardent Defender"] = {
	SpellID = 31850,
	NoGCD = true,
}

spells["Holy Shield"] = {
	SpellID = 20925,
	NoGCD = true,
}

spells["Divine Protection"] = {
	SpellID = 498,
	NoGCD = true,
}

spells["Fire of the Deep"] = {
	ItemID = 77117,
	Buff = "Elusive",
}

spells["Guardian of Ancient Kings"] = {
	SpellID = 86150,
	NoGCD = true,
}

spells["Judgements of the Just"] = {
	SpellID = 20271,
	Debuff = c.SLOW_MELEE_DEBUFFS,
	EarlyRefresh = 3,
}

spells["Delayed Judgement"] = {
	SpellID = 20271,
	ConfigEnabled = "Prot_2pT13",
}

spells["Vindication"] = {
	SpellID = 35395,
	Debuff = c.WEAKEN_DEBUFFS,
	EarlyRefresh = 3,
}

spells["Righteous Fury"] = {
	SpellID = 25780,
	Buff = "Righteous Fury",
	BuffUnit = "player",
}

spells["Holy Wrath to Stun"] = {
	SpellID = 2812,
	ExtraCheck = function()
		level = UnitLevel("target")
		if level == -1 or level > UnitLevel("player") then
			return false
		end
		
		ct = UnitCreatureType("target")
		return UnitLevel("target") <= UnitLevel("player")
			and (ct == "Demon"
				or ct == "Drakonkin"
				or ct == "Elemental"
				or ct == "Undead")
	end
}

-- AddonTable.Castable["English_Spell_Name"] = function()
	-- wipe(z)
	-- z.SpellID = GlobalSpellID--[[English_Spell_Name]]   --this is for defining the correct name of the spell
	-- z.DebuffSlotNeeded = 1   --use this if you want to make sure that a debuff slot is free on the target so that you do not replace other debuffs
	-- z.Debuff = z.SpellID   --place debuff name or table of names here if the spell has a debuff that may only be on a target once in total from everyone and has a cooldown shorter than the debuff duration
	-- z.MyDebuff = z.SpellID   --place debuff name or table of names here if the spell has a debuff that may be on the target multiple times by many people and has a cooldown shorter than the debuff duration
	-- z.Buff = z.SpellID   --place buff name or table of names here if the spell has a buff that may only be on yourself once in total from everyone and has a cooldown shorter than the buff duration
	-- z.MyBuff = z.SpellID   --place buff name or table of names here if the spell has a buff that may be on the target multiple times by many people and has a cooldown shorter than the buff duration
	-- z.BuffUnit = "player"   --you will need to use this if the buff or debuff is not applied to your target
	-- z.Stack = 2   --use this if the buff or debuff requires more than one application
	-- z.EarlyRefresh = 5   --use this to indicate the buff or debuff early for a desired number of seconds
	-- z.CastTime = s.CastTime(z.SpellID)   --use this only if you want to replace the spell cast time used for early indication of a buff or debuff
	-- z.EnemyTargetNeeded = 1   --use this if the spell should have an enemy targeted
	-- z.TargetThatUsesManaNeeded = 1   --use this if the spell is only useful on a target that uses mana such as mana draining spells
	-- z.NoRangeCheck = 1   --use this to disable range detection if the spell has a limited range but the detection in this function is not working correctly for the particular spell
	-- z.NotIfActive = 1   --use this if the spell may be toggled on such as auto attack or on next swing spells, or to disable when casting or channeling, or if the spell has a cooldown
	-- z.NotWhileMoving = 1   --use this if the spell is not able to be cast while moving
	-- z.NoPowerCheck = 1   --use this to disable the power checking in this function
	-- z.EvenIfNotUsable = 1   --use this to disable the usability checking in this function and may be used if currently in the process of completing a prerequisite that will make the spell usable
	-- z.Unit = "target"   --this should not be used unless the spell is not to be cast on the target
	-- z.Interrupt = 1   --use this if the target should be casting or channeling an interruptible ability
	-- return s.CheckIfSpellCastable(z)
-- end
